@@ -51,6 +51,7 @@ gene rows = {}
 
 X_AXIS_CONFIG = """
 [x-axis]
+where = top
 """
 
 VLINES_CONFIG_FORMAT = """
@@ -97,7 +98,8 @@ def make_tracks_file(
     gene_rows=1
 ):
     return (
-        '\n'.join(
+        X_AXIS_CONFIG
+        + '\n'.join(
             BIGWIG_CONFIG_FORMAT.format(
                 file=track,
                 title=os.path.basename(track).split('.')[0],
@@ -108,7 +110,6 @@ def make_tracks_file(
         )
         + SPACER
         + bool(genes) * GENES_CONFIG_FORMAT.format(genes, genes_height, gene_rows)
-        + X_AXIS_CONFIG
         + bool(vlines_bed) * VLINES_CONFIG_FORMAT.format(vlines_bed)
     )
 
